Index: src/wp-includes/widgets.php
===================================================================
--- src/wp-includes/widgets.php	(revision 36183)
+++ src/wp-includes/widgets.php	(working copy)
@@ -281,12 +281,12 @@
  *
  * @global array $wp_registered_sidebars Stores the new sidebar in this array by sidebar ID.
  *
  * @param string $name The ID of the sidebar when it was added.
  */
-function unregister_sidebar( $name ) {
+function unregister_sidebar( $sidebar_id ) {
 	global $wp_registered_sidebars;
 
-	unset( $wp_registered_sidebars[ $name ] );
+	unset( $wp_registered_sidebars[ $sidebar_id ] );
 }
 
 /**
@@ -281,12 +281,12 @@
  * @global array $wp_registered_sidebars Stores the new sidebar in this array by sidebar ID.
  *
- * @param string $name The ID of the sidebar when it was added.
+ * @param string|int $sidebar_id The ID of the sidebar when it was registered.
  */
